#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_INTERLEAVE_EVEN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SIMD_INTERLEAVE_EVEN_HPP_INCLUDED

#include <boost/simd/swar/include/functions/simd/interleave_even.hpp>

#endif
